@@ -17,7 +17,6 @@
 #define R2_DATDIR "/usr/share"
 #endif
 
-#define R2_VERSION "1.5.0"
 #define HAVE_LIB_MAGIC 1
 #define USE_LIB_MAGIC 0
 #ifndef HAVE_LIB_SSL
@@ -30,4 +29,10 @@
 
 #define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
 
+#if __APPLE__ && __POWERPC__
+#define HAVE_JEMALLOC 0
+#else
+#define HAVE_JEMALLOC 1
+#endif
+
 #endif
